.. _release-notes:

Release Notes
=============

v0.1.3 (June 2022)
------------------

Bugfixes
~~~~~~~~

* Fixed exception when slicing with single integer (instead of a range) `#36 <https://github.com/scipp/scipp/pull/36>`_.
* Fixed slicing with bin-edge coords, which previously dropped the upper bound `#36 <https://github.com/scipp/scipp/pull/36>`_.

Contributors
~~~~~~~~~~~~

Simon Heybrock :sup:`a`

v0.1.0 (May 2022)
-----------------

Features
~~~~~~~~

This is the initial non-experimental release of scippnexus.

Contributors
~~~~~~~~~~~~

Simon Heybrock :sup:`a`\ ,
Neil Vaytet :sup:`a`\ ,
and Jan-Lukas Wynen :sup:`a`
